@@ -25,7 +25,7 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
             Program_Line_3='elseif AdapStand == 2',
             Program_Line_4='set ComfTemp = PMOT*0.31+17.8',
             Program_Line_5='elseif AdapStand == 3',
-            Program_Line_6='set ComfTemp = PMOT*0.37+16.8',
+            Program_Line_6='set ComfTemp = PMOT*0.48+14.4',
             Program_Line_7='endif'
         )
         if verboseMode:
@@ -169,7 +169,7 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
             Program_Line_9='set ACSToffset = 4',
             Program_Line_10='set AHSToffset = -5',
             Program_Line_11='endif',
-            Program_Line_12='elseif (AdapStand == 2 )',
+            Program_Line_12='elseif (AdapStand == 2 ) || (AdapStand == 3)',
             Program_Line_13='if (CAT == 90)',
             Program_Line_14='set ACSToffset = 2.5',
             Program_Line_15='set AHSToffset = -2.5',
@@ -177,18 +177,7 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
             Program_Line_17='set ACSToffset = 3.5',
             Program_Line_18='set AHSToffset = -3.5',
             Program_Line_19='endif',
-            Program_Line_20='elseif (AdapStand == 3)',
-            Program_Line_21='if (CAT == 1)',
-            Program_Line_22='set ACSToffset = 2',
-            Program_Line_23='set AHSToffset = -2',
-            Program_Line_24='elseif (CAT == 2)',
-            Program_Line_25='set ACSToffset = 3',
-            Program_Line_26='set AHSToffset = -3',
-            Program_Line_27='elseif (CAT == 3)',
-            Program_Line_28='set ACSToffset = 4',
-            Program_Line_29='set AHSToffset = -4',
-            Program_Line_30='endif',
-            Program_Line_31='endif'
+            Program_Line_20='endif',
         )
         if verboseMode:
             print('Added - ApplyCAT Program')
@@ -319,30 +308,30 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
             Program_Line_116='if (AdapStand == 2) && (ComfMod == 0)',
             Program_Line_117='if (DayOfYear >= 121) && (DayOfYear < 274)',
             Program_Line_118='if (CAT==80)',
-            Program_Line_119='set ACST = 26.8+ACSTtol',
+            Program_Line_119='set ACST = 28.35+ACSTtol',
             Program_Line_120='elseif (CAT==90)',
-            Program_Line_121='set ACST = 25.8+ACSTtol',
+            Program_Line_121='set ACST = 27.42+ACSTtol',
             Program_Line_122='endif',
             Program_Line_123='else',
             Program_Line_124='if (CAT==80)',
-            Program_Line_125='set ACST = 22.9+ACSTtol',
+            Program_Line_125='set ACST = 26.35+ACSTtol',
             Program_Line_126='elseif (CAT==90)',
-            Program_Line_127='set ACST = 23.9+ACSTtol',
+            Program_Line_127='set ACST = 25.09+ACSTtol',
             Program_Line_128='endif',
             Program_Line_129='endif',
             Program_Line_130='endif',
             Program_Line_131='if (AdapStand == 2) && (ComfMod == 0)',
             Program_Line_132='if (DayOfYear >= 121) && (DayOfYear < 274)',
             Program_Line_133='if (CAT==80)',
-            Program_Line_134='set AHST = 24.6+AHSTtol',
+            Program_Line_134='set AHST = 23.78+AHSTtol',
             Program_Line_135='elseif (CAT==90)',
-            Program_Line_136='set AHST = 23.6+AHSTtol',
+            Program_Line_136='set AHST = 24.74+AHSTtol',
             Program_Line_137='endif',
             Program_Line_138='else',
             Program_Line_139='if (CAT==80)',
-            Program_Line_140='set AHST = 18.6+AHSTtol',
+            Program_Line_140='set AHST = 20.1+AHSTtol',
             Program_Line_141='elseif (CAT==90)',
-            Program_Line_142='set AHST = 19.6+AHSTtol',
+            Program_Line_142='set AHST = 21.44+AHSTtol',
             Program_Line_143='endif',
             Program_Line_144='endif',
             Program_Line_145='endif',
@@ -366,62 +355,150 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
             Program_Line_163='elseif (AdapStand == 2) && (ComfMod == 1) && (CurrentTime < 24)',
             Program_Line_164='set AHST = 17+AHSTtol',
             Program_Line_165='endif',
-            Program_Line_166='if (AdapStand == 2) && (ComfMod == 2) && (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
-            Program_Line_167='set ACST = PMOT*0.31+17.8+ACSToffset+ACSTtol',
-            Program_Line_168='elseif (AdapStand == 2) && (ComfMod == 2) && (PMOT < ACSTall)',
-            Program_Line_169='set ACST = 23.9+ACSTtol',
-            Program_Line_170='elseif (AdapStand == 2) && (ComfMod == 2) && (PMOT > ACSTaul)',
-            Program_Line_171='set ACST = 26.8+ACSTtol',
-            Program_Line_172='endif',
-            Program_Line_173='if (AdapStand == 2) && (ComfMod == 2) && (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
-            Program_Line_174='set AHST = PMOT*0.31+17.8+AHSToffset+AHSTtol',
-            Program_Line_175='elseif (AdapStand == 2) && (ComfMod == 2) && (PMOT < AHSTall)',
-            Program_Line_176='set AHST = 19.6+AHSTtol',
-            Program_Line_177='elseif (AdapStand == 2) && (ComfMod == 2) && (PMOT > AHSTaul)',
-            Program_Line_178='set AHST = 23.6+AHSTtol',
-            Program_Line_179='endif',
-            Program_Line_180='if (AdapStand == 2) && (ComfMod == 3) && (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
-            Program_Line_181='set ACST = PMOT*0.31+17.8+ACSToffset+ACSTtol',
-            Program_Line_182='elseif (AdapStand == 2) && (ComfMod == 3) && (PMOT < ACSTall)',
-            Program_Line_183='set ACST = ACSTall*0.31+17.8+ACSToffset+ACSTtol',
-            Program_Line_184='elseif (AdapStand == 2) && (ComfMod == 3) && (PMOT > ACSTaul)',
-            Program_Line_185='set ACST = ACSTaul*0.31+17.8+ACSToffset+ACSTtol',
-            Program_Line_186='endif',
-            Program_Line_187='if (AdapStand == 2) && (ComfMod == 3) && (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
-            Program_Line_188='set AHST = PMOT*0.31+17.8+AHSToffset+AHSTtol',
-            Program_Line_189='elseif (AdapStand == 2) && (ComfMod == 3) && (PMOT < AHSTall)',
-            Program_Line_190='set AHST = AHSTall*0.31+17.8+AHSToffset+AHSTtol',
-            Program_Line_191='elseif (AdapStand == 2) && (ComfMod == 3) && (PMOT > AHSTaul)',
-            Program_Line_192='set AHST = AHSTaul*0.31+17.8+AHSToffset+AHSTtol',
-            Program_Line_193='endif',
-            Program_Line_194='if (AdapStand == 3) && (ComfMod == 2) && (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
-            Program_Line_195='set ACST = PMOT*0.37+16.8+ACSToffset+ACSTtol',
-            Program_Line_196='elseif (AdapStand == 3) && (ComfMod == 2) && (PMOT < ACSTall)',
-            Program_Line_197='set ACST = 23.9+ACSTtol',
-            Program_Line_198='elseif (AdapStand == 3) && (ComfMod == 2) && (PMOT > ACSTaul)',
-            Program_Line_199='set ACST = 26.8+ACSTtol',
-            Program_Line_200='endif',
-            Program_Line_201='if (AdapStand == 3) && (ComfMod == 2) && (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
-            Program_Line_202='set AHST = PMOT*0.37+16.8+AHSToffset+AHSTtol',
-            Program_Line_203='elseif (AdapStand == 3) && (ComfMod == 2) && (PMOT < AHSTall)',
-            Program_Line_204='set AHST = 19.6+AHSTtol',
-            Program_Line_205='elseif (AdapStand == 3) && (ComfMod == 2) && (PMOT > AHSTaul)',
-            Program_Line_206='set AHST = 23.6+AHSTtol',
-            Program_Line_207='endif',
-            Program_Line_208='if (AdapStand == 3) && (ComfMod == 3) && (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
-            Program_Line_209='set ACST = PMOT*0.37+16.8+ACSToffset+ACSTtol',
-            Program_Line_210='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT < ACSTall)',
-            Program_Line_211='set ACST = ACSTall*0.37+16.8+ACSToffset+ACSTtol',
-            Program_Line_212='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT > ACSTaul)',
-            Program_Line_213='set ACST = ACSTaul*0.37+16.8+ACSToffset+ACSTtol',
-            Program_Line_214='endif',
-            Program_Line_215='if (AdapStand == 3) && (ComfMod == 3) && (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
-            Program_Line_216='set AHST = PMOT*0.37+16.8+AHSToffset+AHSTtol',
-            Program_Line_217='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT < AHSTall)',
-            Program_Line_218='set AHST = AHSTall*0.37+16.8+AHSToffset+AHSTtol',
-            Program_Line_219='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT > AHSTaul)',
-            Program_Line_220='set AHST = AHSTaul*0.37+16.8+AHSToffset+AHSTtol',
-            Program_Line_221='endif'
+            Program_Line_166='if (AdapStand == 2) && (ComfMod == 2)',
+            Program_Line_167='if (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
+            Program_Line_168='set ACST = PMOT*0.31+17.8+ACSToffset+ACSTtol',
+            Program_Line_169='elseif CAT==80',
+            Program_Line_170='if PMOT < ACSTall',
+            Program_Line_171='set ACST = 26.35+ACSTtol',
+            Program_Line_172='elseif PMOT > ACSTaul',
+            Program_Line_173='set ACST = 28.35+ACSTtol',
+            Program_Line_174='endif',
+            Program_Line_175='elseif CAT==90',
+            Program_Line_176='if PMOT < ACSTall',
+            Program_Line_177='set ACST = 25.09+ACSTtol',
+            Program_Line_178='elseif PMOT > ACSTaul',
+            Program_Line_179='set ACST = 27.42+ACSTtol',
+            Program_Line_180='endif',
+            Program_Line_181='endif',
+            Program_Line_182='endif',
+            Program_Line_183='if (AdapStand == 2) && (ComfMod == 2)',
+            Program_Line_184='if (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
+            Program_Line_185='set AHST = PMOT*0.31+17.8+AHSToffset+AHSTtol',
+            Program_Line_186='elseif CAT==80',
+            Program_Line_187='if PMOT < AHSTall',
+            Program_Line_188='set AHST = 20.1+AHSTtol',
+            Program_Line_189='elseif PMOT > AHSTaul',
+            Program_Line_190='set AHST = 23.78+AHSTtol',
+            Program_Line_191='endif',
+            Program_Line_192='elseif CAT==90',
+            Program_Line_193='if PMOT < AHSTall',
+            Program_Line_194='set AHST = 21.44+AHSTtol',
+            Program_Line_195='elseif PMOT > AHSTaul',
+            Program_Line_196='set AHST = 24.74+AHSTtol',
+            Program_Line_197='endif',
+            Program_Line_198='endif',
+            Program_Line_199='endif',
+            Program_Line_200='if (AdapStand == 2) && (ComfMod == 3) && (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
+            Program_Line_201='set ACST = PMOT*0.31+17.8+ACSToffset+ACSTtol',
+            Program_Line_202='elseif (AdapStand == 2) && (ComfMod == 3) && (PMOT < ACSTall)',
+            Program_Line_203='set ACST = ACSTall*0.31+17.8+ACSToffset+ACSTtol',
+            Program_Line_204='elseif (AdapStand == 2) && (ComfMod == 3) && (PMOT > ACSTaul)',
+            Program_Line_205='set ACST = ACSTaul*0.31+17.8+ACSToffset+ACSTtol',
+            Program_Line_206='endif',
+            Program_Line_207='if (AdapStand == 2) && (ComfMod == 3) && (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
+            Program_Line_208='set AHST = PMOT*0.31+17.8+AHSToffset+AHSTtol',
+            Program_Line_209='elseif (AdapStand == 2) && (ComfMod == 3) && (PMOT < AHSTall)',
+            Program_Line_210='set AHST = AHSTall*0.31+17.8+AHSToffset+AHSTtol',
+            Program_Line_211='elseif (AdapStand == 2) && (ComfMod == 3) && (PMOT > AHSTaul)',
+            Program_Line_212='set AHST = AHSTaul*0.31+17.8+AHSToffset+AHSTtol',
+            Program_Line_213='endif',
+            Program_Line_214='if (AdapStand == 3) && (ComfMod == 0)',
+            Program_Line_215='if (CAT==80)',
+            Program_Line_216='set ACST = 28+ACSTtol',
+            Program_Line_217='elseif (CAT==90)',
+            Program_Line_218='set ACST = 27+ACSTtol',
+            Program_Line_219='endif',
+            Program_Line_220='endif',
+            Program_Line_221='if (AdapStand == 3) && (ComfMod == 0)',
+            Program_Line_222='if (CAT==80)',
+            Program_Line_223='set AHST = 18+AHSTtol',
+            Program_Line_224='elseif (CAT==90)',
+            Program_Line_225='set AHST = 19+AHSTtol',
+            Program_Line_226='endif',
+            Program_Line_227='endif',
+            Program_Line_228='if (AdapStand == 3) && (ComfMod == 1)',
+            Program_Line_229='if (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
+            Program_Line_230='set ACST = PMOT*0.48+14.4+ACSToffset+ACSTtol',
+            Program_Line_231='elseif CAT==80',
+            Program_Line_232='if PMOT < ACSTall',
+            Program_Line_233='set ACST = 28+ACSTtol',
+            Program_Line_234='elseif PMOT > ACSTaul',
+            Program_Line_235='set ACST = 28+ACSTtol',
+            Program_Line_236='endif',
+            Program_Line_237='elseif CAT==90',
+            Program_Line_238='if PMOT < ACSTall',
+            Program_Line_239='set ACST = 27+ACSTtol',
+            Program_Line_240='elseif PMOT > ACSTaul',
+            Program_Line_241='set ACST = 27+ACSTtol',
+            Program_Line_242='endif',
+            Program_Line_243='endif',
+            Program_Line_244='endif',
+            Program_Line_245='if (AdapStand == 3) && (ComfMod == 1)',
+            Program_Line_246='if (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
+            Program_Line_247='set AHST = PMOT*0.48+14.4+AHSToffset+AHSTtol',
+            Program_Line_248='elseif CAT==80',
+            Program_Line_249='if PMOT < AHSTall',
+            Program_Line_250='set AHST = 18+AHSTtol',
+            Program_Line_251='elseif PMOT > AHSTaul',
+            Program_Line_252='set AHST = 18+AHSTtol',
+            Program_Line_253='endif',
+            Program_Line_254='elseif CAT==90',
+            Program_Line_255='if PMOT < AHSTall',
+            Program_Line_256='set AHST = 19+AHSTtol',
+            Program_Line_257='elseif PMOT > AHSTaul',
+            Program_Line_258='set AHST = 19+AHSTtol',
+            Program_Line_259='endif',
+            Program_Line_260='endif',
+            Program_Line_261='endif',
+            Program_Line_262='if (AdapStand == 3) && (ComfMod == 2)',
+            Program_Line_263='if (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
+            Program_Line_264='set ACST = PMOT*0.48+14.4+ACSToffset+ACSTtol',
+            Program_Line_265='elseif CAT==80',
+            Program_Line_266='if PMOT < ACSTall',
+            Program_Line_267='set ACST = 26.35+ACSTtol',
+            Program_Line_268='elseif PMOT > ACSTaul',
+            Program_Line_269='set ACST = 28.35+ACSTtol',
+            Program_Line_270='endif',
+            Program_Line_271='elseif CAT==90',
+            Program_Line_272='if PMOT < ACSTall',
+            Program_Line_273='set ACST = 25.09+ACSTtol',
+            Program_Line_274='elseif PMOT > ACSTaul',
+            Program_Line_275='set ACST = 27.42+ACSTtol',
+            Program_Line_276='endif',
+            Program_Line_277='endif',
+            Program_Line_278='endif',
+            Program_Line_279='if (AdapStand == 3) && (ComfMod == 2)',
+            Program_Line_280='if (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
+            Program_Line_281='set AHST = PMOT*0.48+14.4+AHSToffset+AHSTtol',
+            Program_Line_282='elseif CAT==80',
+            Program_Line_283='if PMOT < AHSTall',
+            Program_Line_284='set AHST = 20.1+AHSTtol',
+            Program_Line_285='elseif PMOT > AHSTaul',
+            Program_Line_286='set AHST = 23.78+AHSTtol',
+            Program_Line_287='endif',
+            Program_Line_288='elseif CAT==90',
+            Program_Line_289='if PMOT < AHSTall',
+            Program_Line_290='set AHST = 21.44+AHSTtol',
+            Program_Line_291='elseif PMOT > AHSTaul',
+            Program_Line_292='set AHST = 24.74+AHSTtol',
+            Program_Line_293='endif',
+            Program_Line_294='endif',
+            Program_Line_295='endif',
+            Program_Line_296='if (AdapStand == 3) && (ComfMod == 3) && (PMOT >= ACSTall) && (PMOT <= ACSTaul)',
+            Program_Line_297='set ACST = PMOT*0.48+14.4+ACSToffset+ACSTtol',
+            Program_Line_298='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT < ACSTall)',
+            Program_Line_299='set ACST = ACSTall*0.48+14.4+ACSToffset+ACSTtol',
+            Program_Line_300='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT > ACSTaul)',
+            Program_Line_301='set ACST = ACSTaul*0.48+14.4+ACSToffset+ACSTtol',
+            Program_Line_302='endif',
+            Program_Line_303='if (AdapStand == 3) && (ComfMod == 3) && (PMOT >= AHSTall) && (PMOT <= AHSTaul)',
+            Program_Line_304='set AHST = PMOT*0.48+14.4+AHSToffset+AHSTtol',
+            Program_Line_305='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT < AHSTall)',
+            Program_Line_306='set AHST = AHSTall*0.48+14.4+AHSToffset+AHSTtol',
+            Program_Line_307='elseif (AdapStand == 3) && (ComfMod == 3) && (PMOT > AHSTaul)',
+            Program_Line_308='set AHST = AHSTaul*0.48+14.4+AHSToffset+AHSTtol',
+            Program_Line_309='endif',
         )
         if verboseMode:
             print('Added - SetAST Program')
@@ -463,6 +540,20 @@ def addEMSProgramsBase(self, ScriptType: str = None, verboseMode: bool = True):
                 print('Added - CountHoursNoApp_'+zonename+' Program')
     #        print([program for program in self.idf1.idfobjects['EnergyManagementSystem:Program'] if program.Name == 'CountHoursNoApp_'+zonename])
 
+        if 'SetGeoVar'+zonename in programlist:
+            if verboseMode:
+                print('Not added - SetGeoVar'+zonename+' Program')
+        else:
+            self.idf1.newidfobject(
+                'EnergyManagementSystem:Program',
+                Name='SetGeoVar'+zonename,
+                Program_Line_1='set ZoneFloorArea_' + zonename + ' = ZFA_' + zonename + '/2',
+                Program_Line_2='set ZoneAirVolume_' + zonename + ' = ZAV_' + zonename + '/2'
+            )
+            if verboseMode:
+                print('Added - SetGeoVar'+zonename+' Program')
+    #        print([program for program in self.idf1.idfobjects['EnergyManagementSystem:Program'] if program.Name == 'SetGeoVar'+zonename])
+
     if 'SetInputData' in programlist:
         if verboseMode:
             print('Not added - SetInputData Program')
@@ -764,25 +855,25 @@ def addEMSOutputVariableBase(self, ScriptType: str = None, verboseMode: bool = T
     Checks if some EMS output variables objects are already
     in the model, and otherwise adds them.
     """
-    EMSOutputVariableComfTemp_dict = {
-        'Comfort Temperature': 'ComfTemp',
-        'Adaptive Cooling Setpoint Temperature': 'ACST',
-        'Adaptive Heating Setpoint Temperature': 'AHST',
-        'Adaptive Cooling Setpoint Temperature_No Tolerance': 'ACSTnoTol',
-        'Adaptive Heating Setpoint Temperature_No Tolerance': 'AHSTnoTol',
-        }
-    EMSOutputVariableComfTempMM_dict = {
-        'Ventilation Setpoint Temperature': 'VST',
-        'Minimum Outdoor Temperature for ventilation': 'MinOutTemp'
+    EMSOutputVariableAvg_dict = {
+        'Comfort Temperature': ['ComfTemp', 'C'],
+        'Adaptive Cooling Setpoint Temperature': ['ACST', 'C'],
+        'Adaptive Heating Setpoint Temperature': ['AHST', 'C'],
+        'Adaptive Cooling Setpoint Temperature_No Tolerance': ['ACSTnoTol', 'C'],
+        'Adaptive Heating Setpoint Temperature_No Tolerance': ['AHSTnoTol', 'C'],
+    }
+    EMSOutputVariableAvgMM_dict = {
+        'Ventilation Setpoint Temperature': ['VST', 'C'],
+        'Minimum Outdoor Temperature for ventilation': ['MinOutTemp', 'C']
         }
     if ScriptType.lower() == 'vrf' or ScriptType.lower() == 'ex_mm':
-        EMSOutputVariableComfTemp_dict.update(EMSOutputVariableComfTempMM_dict)
+        EMSOutputVariableAvg_dict.update(EMSOutputVariableAvgMM_dict)
 
     outputvariablelist = ([outvar.Name
                            for outvar
                            in self.idf1.idfobjects['EnergyManagementSystem:OutputVariable']])
 
-    for i in EMSOutputVariableComfTemp_dict:
+    for i in EMSOutputVariableAvg_dict:
         if i in outputvariablelist:
             if verboseMode:
                 print('Not added - '+i+' Output Variable')
@@ -790,46 +881,48 @@ def addEMSOutputVariableBase(self, ScriptType: str = None, verboseMode: bool = T
             self.idf1.newidfobject(
                 'EnergyManagementSystem:OutputVariable',
                 Name=i,
-                EMS_Variable_Name=EMSOutputVariableComfTemp_dict[i],
+                EMS_Variable_Name=EMSOutputVariableAvg_dict[i][0],
                 Type_of_Data_in_Variable='Averaged',
                 Update_Frequency='ZoneTimestep',
                 EMS_Program_or_Subroutine_Name='',
-                Units='C'
+                Units=EMSOutputVariableAvg_dict[i][1]
                 )
             if verboseMode:
                 print('Added - '+i+' Output Variable')
             # print([outputvariable for outputvariable in self.idf1.idfobjects['EnergyManagementSystem:OutputVariable'] if outputvariable.Name == i])
 
-    EMSOutputVariableComfHours_dict = {
-        'Comfortable Hours_No Applicability': 'ComfHoursNoApp',
-        'Comfortable Hours': 'ComfHours',
-        'Discomfortable Applicable Hot Hours': 'DiscomfAppHotHours',
-        'Discomfortable Applicable Cold Hours': 'DiscomfAppColdHours',
-        'Discomfortable Non Applicable Hot Hours': 'DiscomfNonAppHotHours',
-        'Discomfortable Non Applicable Cold Hours': 'DiscomfNonAppColdHours',
-        }
+    EMSOutputVariableSum_dict = {
+        'Comfortable Hours_No Applicability': ['ComfHoursNoApp', 'H'],
+        'Comfortable Hours_Applicability': ['ComfHours', 'H'],
+        'Discomfortable Applicable Hot Hours': ['DiscomfAppHotHours', 'H'],
+        'Discomfortable Applicable Cold Hours': ['DiscomfAppColdHours', 'H'],
+        'Discomfortable Non Applicable Hot Hours': ['DiscomfNonAppHotHours', 'H'],
+        'Discomfortable Non Applicable Cold Hours': ['DiscomfNonAppColdHours', 'H'],
+        'Zone Floor Area': ['ZoneFloorArea', 'm2'],
+        'Zone Air Volume': ['ZoneAirVolume', 'm3'],
+    }
 
-    for i in EMSOutputVariableComfHours_dict:
+    for i in EMSOutputVariableSum_dict:
         for zonename in self.occupiedZones:
-            if i+'_'+zonename+' (summed)' in outputvariablelist:
+            if i+'_'+zonename in outputvariablelist:
                 if verboseMode:
                     print('Not added - '+i+'_'
-                          + zonename + ' (summed) Output Variable')
+                          + zonename + ' Output Variable')
             else:
                 self.idf1.newidfobject(
                     'EnergyManagementSystem:OutputVariable',
-                    Name=i + '_' + zonename + ' (summed)',
-                    EMS_Variable_Name=EMSOutputVariableComfHours_dict[i]+'_'
+                    Name=i + '_' + zonename,
+                    EMS_Variable_Name=EMSOutputVariableSum_dict[i][0]+'_'
                     + zonename,
                     Type_of_Data_in_Variable='Summed',
                     Update_Frequency='ZoneTimestep',
                     EMS_Program_or_Subroutine_Name='',
-                    Units='H'
+                    Units=EMSOutputVariableSum_dict[i][1]
                     )
                 if verboseMode:
                     print('Added - '+i+'_'
-                          + zonename + ' (summed) Output Variable')
-                # print([outputvariable for outputvariable in self.idf1.idfobjects['EnergyManagementSystem:OutputVariable'] if outputvariable.Name == i+'_'+zonename+' (summed)'])
+                          + zonename + ' Output Variable')
+                # print([outputvariable for outputvariable in self.idf1.idfobjects['EnergyManagementSystem:OutputVariable'] if outputvariable.Name == i+'_'+zonename'])
 
     if ScriptType.lower() == 'vrf' or ScriptType.lower() == 'ex_mm':
         EMSOutputVariableIDFzones_dict = {
@@ -838,14 +931,14 @@ def addEMSOutputVariableBase(self, ScriptType: str = None, verboseMode: bool = T
 
         for i in EMSOutputVariableIDFzones_dict:
             for zonename in self.zonenames:
-                if i+'_'+zonename+' (summed)' in outputvariablelist:
+                if i+'_'+zonename in outputvariablelist:
                     if verboseMode:
                         print('Not added - '+i+'_'
-                              + zonename + ' (summed) Output Variable')
+                              + zonename + ' Output Variable')
                 else:
                     self.idf1.newidfobject(
                         'EnergyManagementSystem:OutputVariable',
-                        Name=i + '_' + zonename + ' (summed)',
+                        Name=i + '_' + zonename,
                         EMS_Variable_Name=EMSOutputVariableIDFzones_dict[i]+'_'
                         + zonename,
                         Type_of_Data_in_Variable='Summed',
@@ -855,8 +948,8 @@ def addEMSOutputVariableBase(self, ScriptType: str = None, verboseMode: bool = T
                         )
                     if verboseMode:
                         print('Added - '+i+'_'
-                              + zonename + ' (summed) Output Variable')
-                    # print([outputvariable for outputvariable in self.idf1.idfobjects['EnergyManagementSystem:OutputVariable'] if outputvariable.Name == i+'_'+zonename+' (summed)'])
+                              + zonename + ' Output Variable')
+                    # print([outputvariable for outputvariable in self.idf1.idfobjects['EnergyManagementSystem:OutputVariable'] if outputvariable.Name == i+'_'+zonename'])
 
     del outputvariablelist
 
@@ -898,8 +991,11 @@ def addGlobVarList(self, ScriptType: str = None, verboseMode: bool = True):
             Erl_Variable_3_Name='DiscomfAppColdHours_'+zonename,
             Erl_Variable_4_Name='DiscomfNonAppHotHours_'+zonename,
             Erl_Variable_5_Name='DiscomfNonAppColdHours_'+zonename,
-            Erl_Variable_6_Name='ComfHoursNoApp_'+zonename
-            )
+            Erl_Variable_6_Name='ComfHoursNoApp_'+zonename,
+            Erl_Variable_7_Name='ZoneFloorArea_' + zonename,
+            Erl_Variable_8_Name='ZoneAirVolume_' + zonename
+
+        )
 
     if ScriptType.lower() == 'vrf' or ScriptType.lower() == 'ex_mm':
         self.idf1.newidfobject(
@@ -921,6 +1017,32 @@ def addGlobVarList(self, ScriptType: str = None, verboseMode: bool = True):
     if verboseMode:
         print("Global variables objects have been added")
 
+def addIntVarList(self, verboseMode: bool = True):
+    """Add Internal variables objects for accim."""
+    internalvariablelist = ([program for program in self.idf1.idfobjects['ENERGYMANAGEMENTSYSTEM:INTERNALVARIABLE']])
+
+    for i in range(len(internalvariablelist)):
+        firstinternalvariablelist = self.idf1.idfobjects['ENERGYMANAGEMENTSYSTEM:INTERNALVARIABLE'][-1]
+        self.idf1.removeidfobject(firstinternalvariablelist)
+
+    del internalvariablelist
+
+    intvardict = {
+        'ZFA_': 'Zone Floor Area',
+        'ZAV_': 'Zone Air Volume'
+    }
+
+    for i in range(len(self.zonenames)):
+        for j in intvardict:
+            self.idf1.newidfobject(
+                'EnergyManagementSystem:InternalVariable',
+                Name=j+self.zonenames[i],
+                Internal_Data_Index_Key_Name=self.zonenames_orig[i],
+                Internal_Data_Type=intvardict[j]
+            )
+    if verboseMode:
+        print("Internal variables objects have been added")
+
 # todo add argument for mm outputvariables
 def addOutputVariablesBase(self, ScriptType: str = None, verboseMode: bool = True):
     """Add Output:Variable objects for accim."""
@@ -948,11 +1070,13 @@ def addOutputVariablesBase(self, ScriptType: str = None, verboseMode: bool = Tru
     addittionaloutputs = [
         'Zone Thermostat Operative Temperature',
         'Zone Thermal Comfort CEN 15251 Adaptive Model Running Average Outdoor Air Temperature',
+        'Zone Thermal Comfort ASHRAE 55 Adaptive Model Running Average Outdoor Air Temperature',
         'Cooling Coil Total Cooling Rate',
         'Heating Coil Heating Rate',
         'Facility Total HVAC Electric Demand Power',
         'Facility Total HVAC Electricity Demand Rate',
-        'AFN Surface Venting Window or Door Opening Factor',
+        # todo maybe create a new output type to include this variable, to be used in case of tests
+        # 'AFN Surface Venting Window or Door Opening Factor',
         'AFN Zone Infiltration Air Change Rate',
         'AFN Zone Infiltration Volume'
         ]
@@ -992,15 +1116,62 @@ def addOutputVariablesBase(self, ScriptType: str = None, verboseMode: bool = Tru
 
     del outputvariablelist, outputlist, addittionaloutputs,
 
-    self.idf1.newidfobject(
-        'Output:Variable',
-        Key_Value='Environment',
-        Variable_Name='Site Outdoor Air Drybulb Temperature',
-        Reporting_Frequency='Hourly',
-        Schedule_Name=''
-        )
-    if verboseMode:
-        print('Added - Site Outdoor Air Drybulb Temperature Output:Variable data')
+    siteAddOutputs = [
+        'Site Outdoor Air Drybulb Temperature',
+        'Site Wind Speed',
+        'Site Outdoor Air Relative Humidity'
+    ]
+
+    other_site_outputs = [
+        'Site Outdoor Air Drybulb Temperature [C]',
+        'Site Outdoor Air Dewpoint Temperature [C]',
+        'Site Outdoor Air Wetbulb Temperature [C]',
+        'Site Outdoor Air Humidity Ratio [kgWater/kgAir]',
+        'Site Outdoor Air Relative Humidity [%]',
+        'Site Outdoor Air Barometric Pressure [Pa]',
+        'Site Wind Speed [m/s]',
+        'Site Wind Direction [deg]',
+        'Site Sky Temperature [C]',
+        'Site Horizontal Infrared Radiation Rate per Area [W/m2]',
+        'Site Difuse Solar Radiation Rate per Area [W/m2]',
+        'Site Direct Solar Radiation Rate per Area [W/m2]',
+        'Site Total Sky Cover []',
+        'Site Opaque Sky Cover []',
+        'Site Precipitation Depth [m]',
+        'Site Ground Refected Solar Radiation Rate per Area [W/m2]',
+        'Site Ground Temperature [C]',
+        'Site Surface Ground Temperature [C]',
+        'Site Deep Ground Temperature [C]',
+        'Site Simple Factor Model Ground Temperature [C]',
+        'Site Outdoor Air Enthalpy [J/kg]',
+        'Site Outdoor Air Density [kg/m3]',
+        'Site Solar Azimuth Angle [deg]',
+        'Site Solar Altitude Angle [deg]',
+        'Site Solar Hour Angle [deg]',
+        'Site Rain Status []',
+        'Site Snow on Ground Status []',
+        'Site Exterior Horizontal Sky Illuminance [lux]',
+        'Site Exterior Horizontal Beam Illuminance [lux]',
+        'Site Exterior Beam Normal Illuminance [lux]',
+        'Site Sky Difuse Solar Radiation Luminous Eﬀcacy [lum/W]',
+        'Site Beam Solar Radiation Luminous Eﬀcacy [lum/W]',
+        'Site Daylighting Model Sky Clearness []',
+        'Sky Brightness for Daylighting Calculation []',
+        'Site Daylight Saving Time Status []',
+        'Site Day Type Index []',
+        'Site Mains Water Temperature [C]',
+    ]
+
+    for addittionaloutput in siteAddOutputs:
+        self.idf1.newidfobject(
+            'Output:Variable',
+            Key_Value='Environment',
+            Variable_Name=addittionaloutput,
+            Reporting_Frequency='Hourly',
+            Schedule_Name=''
+            )
+        if verboseMode:
+            print('Added - '+addittionaloutput+' Output:Variable data')
 
     for zonename in self.zonenames:
         self.idf1.newidfobject(
@@ -1034,16 +1205,6 @@ def addOutputVariablesBase(self, ScriptType: str = None, verboseMode: bool = Tru
         if verboseMode:
             print('Added - '+zonename+' Zone Operative Temperature Output:Variable data')
 
-        self.idf1.newidfobject(
-            'Output:Variable',
-            Key_Value=zonename,
-            Variable_Name='Zone Outdoor Air Wind Speed',
-            Reporting_Frequency='Hourly',
-            Schedule_Name=''
-            )
-        if verboseMode:
-            print('Added - '+zonename+' Zone Outdoor Air Wind Speed Output:Variable data')
-
     if ScriptType.lower() == 'vrf':
         VRFoutputs = [
             'VRF Heat Pump Cooling Electricity Energy',
