@@ -208,7 +208,7 @@ def genIDF(self,
 
     outputlist = []
     for file in filelist_pymod:
-        filename = file
+        filename = file.replace('_pymod', '')
         for AdapStand_value in self.AdapStand_List:
             if AdapStand_value == 0:
                 for HVACmode_value in self.HVACmode_List:
@@ -250,7 +250,7 @@ def genIDF(self,
                                                 + '.idf'
                                                 )
                                             outputlist.append(outputname)
-            elif AdapStand_value == 1 or AdapStand_value == 3:
+            elif AdapStand_value == 1:
                 for CAT_value in self.CAT_List:
                     if CAT_value not in range(0, 4):
                         continue
@@ -295,7 +295,7 @@ def genIDF(self,
                                                             + '.idf'
                                                             )
                                                         outputlist.append(outputname)
-            elif AdapStand_value == 2:
+            elif AdapStand_value == 2 or AdapStand_value == 3:
                 for CAT_value in self.CAT_List:
                     if CAT_value not in range(80, 91, 10):
                         continue
@@ -361,6 +361,8 @@ def genIDF(self,
             filename = file
 
             fname1 = filename+'.idf'
+
+            filename = file.replace('_pymod', '')
             # if verboseMode:
             #     print(f'Taking "{fname1}" as input IDF file:')
             idf1 = IDF(fname1)
@@ -430,7 +432,7 @@ def genIDF(self,
                                                     # time.sleep(0.1)
                                                     # pbar.update(1)
                                                 idf1.savecopy(outputname)
-                elif AdapStand_value == 1 or AdapStand_value == 3:
+                elif AdapStand_value == 1:
                     for CAT_value in self.CAT_List:
                         if CAT_value not in range(0, 4):
                             continue
@@ -494,7 +496,7 @@ def genIDF(self,
                                                                 # time.sleep(0.1)
                                                                 # pbar.update(1)
                                                             idf1.savecopy(outputname)
-                elif AdapStand_value == 2:
+                elif AdapStand_value == 2 or AdapStand_value == 3:
                     for CAT_value in self.CAT_List:
                         if CAT_value not in range(80, 91, 10):
                             continue
