@@ -18,6 +18,7 @@ class accimJob():
         addEMSProgramsBase, \
         addEMSSensorsBase, \
         addGlobVarList, \
+        addIntVarList, \
         addOutputVariablesBase, \
         addOutputVariablesTimestep, \
         addSimplifiedOutputVariables
@@ -82,7 +83,7 @@ class accimJob():
         for i in self.idf1.idfobjects['ZONE']:
             for k in self.idf1.idfobjects['PEOPLE']:
                 if i.Name in k.Name:
-                    self.occupiedZones_orig.append(i.Name)
+                    self.occupiedZones_orig.append(i.Name.upper())
         self.occupiedZones = [i.replace(':', '_') for i in self.occupiedZones_orig]
         if verboseMode:
             print(f'The occupied zones in the model {filename_temp} are:')
@@ -139,8 +140,8 @@ class accimJob():
                 if len(self.idf1.idfobjects[TSPtypes[i]]) > 0:
                     for j in range(len(self.ZCTlist)):
                         if self.ZCTlist[j].Control_1_Object_Type in TSPtypes[i]:
-                            temp1.append(self.ZCTlist[j].Zone_or_ZoneList_Name)
-                            temp2.append(self.ZCTlist[j].Zone_or_ZoneList_Name.replace(":", "_"))
+                            temp1.append(self.ZCTlist[j].Zone_or_ZoneList_Name.upper())
+                            temp2.append(self.ZCTlist[j].Zone_or_ZoneList_Name.upper().replace(":", "_"))
                             temp3.append(self.ZCTlist[j].Control_1_Name)
                 self.HVACzonelist.append([TSPtypes[i], temp1, temp2, temp3])
             del temp1, temp2, temp3
@@ -173,7 +174,7 @@ class accimJob():
 
                 self.HVACdict = {
                     # todo if there is a Coil:Heating:Whatever and another Coil:Heating:DifferentWhatever
-                    #  coils and windows sensors will be duplicated and simuation will crash; it needs to be solved.
+                    #  coils and windows sensors will be duplicated and simulation will crash; it needs to be solved.
 
                     # Group Heating and Cooling Coils
                     'Coil:Cooling:Water': 'Cooling Coil Total Cooling Rate',
