@@ -61,7 +61,7 @@ def addAccis(
     from os import listdir, remove
 
     filelist = ([file for file in listdir() if file.endswith('.idf')
-                 and not '_pymod' in file])
+                 and not '[' in file])
 
     filelist = ([file.split('.idf')[0] for file in filelist])
 
@@ -174,6 +174,7 @@ def addAccis(
         z.addEMSProgramsBase(ScriptType=ScriptType, verboseMode=verboseMode)
         z.addEMSOutputVariableBase(ScriptType=ScriptType, verboseMode=verboseMode)
         z.addGlobVarList(ScriptType=ScriptType, verboseMode=verboseMode)
+        z.addIntVarList(verboseMode=verboseMode)
         z.addEMSSensorsBase(ScriptType=ScriptType, verboseMode=verboseMode)
         z.addEMSActuatorsBase(ScriptType=ScriptType, verboseMode=verboseMode)
 
